==> nextcloud-25.0.1.zip: nextcloud/apps/circles/l10n/sl.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Krogi",
    "Circles' files" : "Datoteke kroga",
    "Select circles to filter by" : "Izbor krogov za filtriranje",
    "No circles found" : "Ni najdenih krogov",
    "Please select circles to filter by" : "Izbor krogov za filtriranje",
    "No files found for the selected circles" : "Ni izbranih datotek za izbrane kroge",
    "You created the circle {circle}" : "Ustvarili ste krog {circle}",
    "{author} created the circle {circle}" : "{author} ustvari krog {circle}",
    "You deleted {circle}" : "Izbrišete krog {circle}",
    "{author} deleted {circle}" : "{author} izbriše krog {circle}",
    "You linked {group} to {circle}" : "Povežete skupino {group} v krog {circle}",
    "{group} has been linked to {circle} by {author}" : "{author} poveže skupino {group} s krogom {circle}",
    "You unlinked {group} from {circle}" : "Odstranite povezavo skupine {group} iz kroga {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{author} odstrani povezavo skupine {group} s krogom {circle}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Spremenili ste vlogo povezane skupine {group} v krogu {circle} v %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} spremeni vlogo povezane skupine {group} v krogu {circle} v %1$s",
    "You sent a request to link {circle} with {remote}" : "Poslali ste prošnjo za povezavo kroga {circle} z oddaljenim {remote}.",
    "{author} sent a request to link {circle} with {remote}" : "{author} pošlje prošnjo za povezavo kroga {circle} z {remote}",
    "{remote} requested a link with {circle}" : "{remote} je poslal prošnjo za vključitev v krog {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Prošnja za povezavo kroga {circle} z {remote} je bila zavrnjena",
    "The request to link {remote} with {circle} has been canceled remotely" : "Prošnja za povezavo mesta {remote} s krogom {circle} je oddaljeno preklicana",
    "The request to link {circle} with {remote} has been accepted" : "Prošnja za povezavo kroga {circle} z {remote} je potrjena",
    "You dismissed the request to link {remote} with {circle}" : "Opustite prošnjo za povezavo {remote} s krogom {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} opusti prošnjo za povezavo {remote} s krogom {circle}",
    "You canceled the request to link {circle} with {remote}" : "Prekličete prošnjo za povezavo kroga {circle} z mestom {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} prekliče prošnjo za povezavo kroga {circle} z mestom {remote}",
    "You accepted the request to link {remote} with {circle}" : "Sprejmete prošnjo za povezavo {remote} s krogom {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} sprejme prošnjo za povezavo {remote} s krogom {circle}",
    "A link between {circle} and {remote} is now up and running" : "Povezava med krogom {circle} in oddaljenim {remote} je sedaj omogočena.",
    "The link between {circle} and {remote} has been shutdown remotely" : "Povezava med krogom {circle} in {remote} je bila oddaljeno izklopljena",
    "You closed the link between {circle} and {remote}" : "Zaprete povezavo med krogom {circle} in oddaljenim {remote}.",
    "{author} closed the link between {circle} and {remote}" : "{author} zapre povezavo med krogom {circle} in {remote}",
    "You joined {circle}" : "Pridružite se krogu {circle}",
    "{member} joined {circle}" : "{member} se pridruži krogu {circle}",
    "You accepted the invitation to join {circle}" : "Sprejmete povabilo v krog {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} sprejme vabilo za pristop v krog {circle}",
    "You added {member} as member to {circle}" : "V krog {circle} ste dodali osebo {member}",
    "You have been added as member to {circle} by {author}" : "{author} vas doda v krog {circle}",
    "{member} has been added as member to {circle} by {author}" : "Račun {member} je bil dodan v članstvo kroga {circle} prek uporabnika {author}",
    "You added {external} to {circle}" : "V krog {circle} je dodana oseba {external}",
    "{external} has been added to {circle} by {author}" : "{external} je bil dodan v članstvo kroga {circle} prek uporabnika {author}",
    "You accepted {member}'s request to join {circle}" : "Sprejeli ste prošnjo člana {member} za pristop v krog {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} sprejme vašo prošnjo za članstvo v krogu {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} sprejme prošnjo člana {member} za članstvo v krogu  {circle}",
    "You left {circle}" : "Zapustite krog {circle}",
    "{member} left {circle}" : "{member} zapusti krog {circle}",
    "You declined the invitation to join {circle}" : "Zavrnete vabilo v krog {circle}",
    "{member} declined an invitation to join {circle}" : "{member} zavrne povabilo v krog {circle}",
    "You cancelled your request to join {circle}" : "Prekličete prošnjo za pristop v krog {circle}",
    "{member} cancelled his request to join {circle}" : "{member} prekliče prošnjo za pristop v krog {circle}",
    "You removed {member} from {circle}" : "Iz kroga {circle} odstranite člana: {member}",
    "You have been removed from {circle} by {author}" : "{author} vas odstrani iz kroga {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} odstrani člana {member} iz kroga {circle}",
    "You removed {external} from {circle}" : "Odstranite zunanji račun {external} iz kroga {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} odstrani zunanji račun {external} iz kroga {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Članu {member} prekličete povabilo v krog {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} prekliče povabilo v krog {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} prekliče članu {member} povabilo v krog {circle}",
    "You dismissed {member}'s request to join {circle}" : "Zavrnete prošnjo člana {member} za pristop v krog {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} zavrne vašo prošnjo za članstvo v krogu {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} zavrne prošnjo člana {member} za članstvo v krogu  {circle}",
    "You invited {member} to join {circle}" : "Člana {member} povabite v krog {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vas povabi v krog {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} povabi člana {member} v krog {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Spremenite vlogo člana {member} iz kroga {circle} v %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} spremeni vašo vlogo v krogu {circle} v %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} spremeni vlogo člana {member} iz kroga {circle} v %1$s",
    "You sent a request to join {circle}" : "Poslali ste prošnjo za pristop v krog {circle}",
    "{member} sent a request to join {circle}" : "{member} pošlje prošnjo za pristop v krog {circle}",
    "You are the new owner of {circle}" : "Postanete novi lastnik kroga {circle}",
    "{member} is the new owner of {circle}" : "{member} postane novi lastnik kroga {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Obvestila za dogodke v <strong>krogih</strong>, v katere ste vključeni",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Obvestila za pomembne dogodke v <strong>krogih</strong>, ki jih moderirate",
    "On global events happening in any <strong>Circle</strong>" : "Za splošne dogodke v kateremkoli <strong>krogu</strong>",
    "Single" : "Enojni",
    "Personal" : "Osebni",
    "System" : "Sistem",
    "Visible" : "Vidno",
    "Open" : "Odpri",
    "Invite" : "Povabi",
    "Join Request" : "Zahteva za pridružitev",
    "Friends" : "Prijatelji",
    "Password Protected" : "Zaščiteno z geslom",
    "No Owner" : "Ni lastnika",
    "Hidden" : "Skrito",
    "Backend" : "Ozadnji program",
    "Local" : "Krajevno",
    "Root" : "Koren",
    "Circle Invite" : "Povabilo v krog",
    "Federated" : "Zvezno",
    "Mount point" : "Priklopna točka",
    "Nextcloud Group" : "Skupina Nextcloud",
    "Email Address" : "Elektronski naslov",
    "Contact" : "Stik",
    "Circle" : "Krog",
    "Nextcloud App" : "Program Nextcloud",
    "Member" : "Član",
    "Moderator" : "Moderator",
    "Admin" : "Skrbnik",
    "Owner" : "Lastnik",
    "%s shared »%s« with you." : "%s vam omogoča souporabo »%s«.",
    "%s shared »%s« with \"%s\"." : "%s omogoči souporabo »%s« z »%s«.",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s vam omogoči souporabo »%2$s«.\nMorali bi že prejeti ločeno sporočilo s povezavo po elektronski pošti.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s vam omogoči souporabo »%2$s«.\nMorali bi že prejeti ločeno sporočilo s povezavo po elektronski pošti.",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s vam pošilja geslo za dostop do datoteke »%1$s«.",
    "Password to access »%s«" : "Geslo za dostop do »%s«",
    "It is protected with the following password:" : "Zaščiten je z geslom:",
    "%1$s via %2$s" : "%1$s prek %2$s",
    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
    "Open »%s«" : "Odpri »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s vam omogoča souporabo več datotek.\nPo elektronski pošti bi morali prejeti tudi sporočilo s povezavo.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s vam omogoča souporabo več datotek. Po elektronski pošti bi morali prejeti tudi sporočilo s povezavo.",
    "Password to access files shared to you by %1$s" : "%1$s vam pošilja geslo za dostop do datoteke v souporabi.",
    "Password to access files" : "Geslo za dostop do datotek",
    "%s shared multiple files with \"%s\"." : "%s omogoči souporabo več datotek z uporabnikom \"%s\".",
    "%s shared multiple files with you." : "%s vam omogoči souporabo več datotek.",
    "Boot up" : "Zaganjanje",
    "Initialisation Nextcloud" : "Začenjanje okolja Nextcloud",
    "Initialisation Circles App" : "Začenjanje programa Krogi",
    "Fresh installation status" : "Stanje sveže namestitve",
    "Building Local Database" : "Poteka izgradnja krajevne podatkovne zbirke",
    "Testing Basic Circle Creation" : "Preizkušanje ustvarjanja osnovnega kroga",
    "Adding local users and moderators" : "Dodajanje krajevnih uporabnikov in moderatorjev",
    "Circle not found" : "Kroga ni mogoče najti",
    "Circle not found " : "Kroga ni mogoče najti",
    "A circle with that name exists" : "Krog s tem imenom že obstaja",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Programa Krogi ni mogoče uporabljati, dokler skrbnik ne omogoči vsaj ene vrste kroga.",
    "This member does not exist" : "Član ne obstaja",
    "Federated link not found" : "Zvezne povezave ni mogoče najti",
    "This feature is not available for personal circles" : "Ta zmožnost za osebne kroge ni na voljo",
    "The circle is not federated" : "Krog ni zvezni krog",
    "You cannot join this circle" : "V ta krog se brez povabila ni mogoče pridružiti",
    "This member is not a moderator" : "Član ni moderator",
    "Insufficient privileges" : "Neustrezna dovoljenja",
    "This member is the owner of the circle" : "Član je lastnik kroga",
    "Level cannot be changed for this type of member" : "Vloge za to vrsto člana ni mogoče spremeniti",
    "You are already a member of this circle" : "Ste že član tega kroga.",
    "You have been blocked from this circle" : "Iz tega kroga ste bili izločeni",
    "You are now a member of the Circle \"%2$s\"" : "Sedaj ste včlanjeni v krog »%2$s«.",
    "You have been invited by %1$s into the Circle \"%2$s\"" : " %1$s vas povabi v krog »%2$s«",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s pošlje prošnjo za včlanitev v krog »%2$s«",
    "Accept" : "Sprejmi",
    "Refuse" : "Zavrni",
    "Leave the circle" : "Zapusti krog",
    "%s" : "%s",
    "Personal Circle" : "Osebni krog",
    "%s owned by %s" : "%s v lasti %s",
    "You need a specify a type of circle" : "Določiti je treba vrsto kroga",
    "This member is not the owner of the circle" : "Ta član ni lastnik kroga",
    "This member is not an admin of the circle" : "Ta član ni skrbnik kroga",
    "Group contains too many members" : "V skupini je preveč članov",
    "This group does not exist" : "Ta skupina ne obstaja.",
    "This group is already linked to the circle" : "Ta skupina je s krogom že povezana.",
    "You cannot edit level in a personal circle" : "Ni mogoče urediti vloge v osebnem krogu",
    "Group cannot be set as owner of a circle" : "Skupine ni mogoče določiti kot lastnika kroga.",
    "now" : "zdaj",
    "Email format is not valid" : "Zapis elektronskega naslova ni veljaven",
    "This contact is not available" : "Ta stik ni na voljo.",
    "%s shared a file with \"%s\"." : "%s omogoča souporabo datoteke z \"%s\".",
    "%s shared a file with you." : "%s omogoča souporabo datoteke z vami.",
    "This item is already shared with this circle" : "Ta predmet je v tem krogu že v souporabi",
    "Could not find share" : "Mesta souporabe ni mogoče najti",
    "Bring cloud-users closer together." : "Potegnite uporabnike oblakov bliže skupaj.",
    "No files in here" : "V mapi ni datotek",
    "No entries found in this folder" : "V tej mapi ni datotek in podmap.",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "Nextcloud User" : "Uporabnik Nextcloud",
    "This user is already a member of the circle" : "Uporabnik je že član kroga.",
    "The user is already a member of this circle" : "Uporabnik je že član kroga.",
    "The user has already been invited into this circle" : "Uporabnik je že bil povabljen v krog.",
    "This user does not exist" : "Uporabnik s tem imenom ne obstaja",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Program Krogi omogoča uporabnikom ustvariti lastne skupine uporabnikov, sodelavcev, prijateljev ...\nTe skupine uporabnikov (oziroma »krogov«) je nato mogoče uporabiti kot skupine za souporabo in izmenjavo datotek in podatkov v različnih programih."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-26.0.13.zip: nextcloud/apps/circles/l10n/sl.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Izbrišete krog {circle}",
    "{author} deleted {circle}" : "{author} izbriše krog {circle}",
    "You joined {circle}" : "Pridružite se krogu {circle}",
    "{member} joined {circle}" : "{member} se pridruži krogu {circle}",
    "You accepted the invitation to join {circle}" : "Sprejmete povabilo v krog {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} sprejme vabilo za pristop v krog {circle}",
    "You added {member} as member to {circle}" : "V krog {circle} ste dodali osebo {member}",
    "You have been added as member to {circle} by {author}" : "{author} vas doda v krog {circle}",
    "{member} has been added as member to {circle} by {author}" : "Račun {member} je avtor {author} dodal v članstvo kroga {circle}.",
    "You added {external} to {circle}" : "V krog {circle} je dodana oseba {external}",
    "{external} has been added to {circle} by {author}" : "{external} je avtor {author} dodal v članstvo kroga {circle}.",
    "You accepted {member}'s request to join {circle}" : "Sprejeli ste prošnjo člana {member} za pristop v krog {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} sprejme vašo prošnjo za članstvo v krogu {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} sprejme prošnjo člana {member} za članstvo v krogu {circle}",
    "You left {circle}" : "Zapustite krog {circle}",
    "{member} left {circle}" : "{member} zapusti krog {circle}",
    "You declined the invitation to join {circle}" : "Zavrnete vabilo v krog {circle}",
    "{member} declined an invitation to join {circle}" : "{member} zavrne povabilo v krog {circle}",
    "You cancelled your request to join {circle}" : "Prekličete prošnjo za pristop v krog {circle}",
    "You removed {member} from {circle}" : "Iz kroga {circle} odstranite člana: {member}",
    "You have been removed from {circle} by {author}" : "{author} vas odstrani iz kroga {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} odstrani člana {member} iz kroga {circle}",
    "You removed {external} from {circle}" : "Odstranite zunanji račun {external} iz kroga {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} odstrani zunanji račun {external} iz kroga {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Članu {member} prekličete povabilo v krog {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} prekliče povabilo v krog {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} prekliče članu {member} povabilo v krog {circle}",
    "You dismissed {member}'s request to join {circle}" : "Zavrnete prošnjo člana {member} za pristop v krog {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} zavrne vašo prošnjo za članstvo v krogu {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} zavrne prošnjo člana {member} za članstvo v krogu  {circle}",
    "You invited {member} to join {circle}" : "Člana {member} povabite v krog {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vas povabi v krog {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} povabi člana {member} v krog {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Spremenite vlogo člana {member} iz kroga {circle} v %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} spremeni vašo vlogo v krogu {circle} v %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} spremeni vlogo člana {member} iz kroga {circle} v %1$s",
    "You sent a request to join {circle}" : "Poslali ste prošnjo za pristop v krog {circle}",
    "{member} sent a request to join {circle}" : "{member} pošlje prošnjo za pristop v krog {circle}",
    "You are the new owner of {circle}" : "Postanete novi lastnik kroga {circle}",
    "{member} is the new owner of {circle}" : "{member} postane novi lastnik kroga {circle}",
    "Shared to Circles" : "Souporaba v krogu",
    "Single" : "Enojni",
    "Personal" : "Osebni",
    "System" : "Sistem",
    "Visible" : "Vidno",
    "Open" : "Odpri",
    "Invite" : "Povabi",
    "Friends" : "Prijatelji",
    "Password protected" : "Zaščiteno z geslom",
    "No Owner" : "Ni lastnika",
    "Hidden" : "Skrito",
    "Backend" : "Ozadnji program",
    "Local" : "Krajevno",
    "Root" : "Koren",
    "Federated" : "Zvezno",
    "Mount point" : "Priklopna točka",
    "Nextcloud Account" : "Račun Nextcloud",
    "Nextcloud Group" : "Skupina Nextcloud",
    "Email address" : "Elektronski naslov",
    "Contact" : "Stik",
    "Circle" : "Krog",
    "Nextcloud App" : "Program Nextcloud",
    "Member" : "Član",
    "Moderator" : "Moderator",
    "Admin" : "Skrbnik",
    "Owner" : "Lastnik",
    "%s shared »%s« with you." : "%s vam omogoča souporabo »%s«.",
    "%s shared »%s« with \"%s\"." : "%s omogoči souporabo »%s« z »%s«.",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s vam omogoči souporabo »%2$s«.\nPo elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s vam omogoči souporabo »%2$s«.\nPo elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.",
    "Password to access »%1$s« shared to you by %2$s" : "%2$s vam pošilja geslo za dostop do datoteke »%1$s«.",
    "Password to access »%s«" : "Geslo za dostop do »%s«",
    "It is protected with the following password:" : "Zaščiten je z geslom:",
    "%1$s via %2$s" : "%1$s prek %2$s",
    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
    "Open »%s«" : "Odpri »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s vam omogoča souporabo več datotek.\nPo elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s vam omogoča souporabo več datotek. Po elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.",
    "Password to access files shared to you by %1$s" : "%1$s vam pošilja geslo za dostop do datoteke v souporabi.",
    "Password to access files" : "Geslo za dostop do datotek",
    "%s shared multiple files with \"%s\"." : "%s omogoči souporabo več datotek z uporabnikom »%s«.",
    "%s shared multiple files with you." : "%s vam omogoči souporabo več datotek.",
    "Boot up" : "Zaganjanje",
    "Nextcloud Initialization" : "Zaganjanje oblaka Nextcloud",
    "Circles App Initialization" : "Zaganjanje programa Krogi",
    "Fresh installation status" : "Stanje sveže namestitve",
    "Building Local Database" : "Poteka izgradnja krajevne podatkovne zbirke",
    "Testing Basic Circle Creation" : "Preizkušanje ustvarjanja osnovnega kroga",
    "Adding local users and moderators" : "Dodajanje krajevnih uporabnikov in moderatorjev",
    "Files" : "Datoteke",
    "This feature is not available for personal circles" : "Ta zmožnost za osebne kroge ni na voljo",
    "This member is not a moderator" : "Član ni moderator",
    "Insufficient privileges" : "Neustrezna dovoljenja",
    "This member does not exist" : "Član ne obstaja",
    "Level cannot be changed for this type of member" : "Vloge za to vrsto člana ni mogoče spremeniti",
    "You are already a member of this circle" : "Ste že član tega kroga.",
    "You have been blocked from this circle" : "Iz tega kroga ste bili izločeni",
    "The account is already a member of this circle" : "Račun ima že potrjeno članstvo v krogu.",
    "The account has already been invited into this circle" : "Račun je že prejel vabilo za članstvo v krogu.",
    "You are now a member of the Circle \"%2$s\"" : "Sedaj ste včlanjeni v krog »%2$s«.",
    "You have been invited by %1$s into the Circle \"%2$s\"" : " %1$s vas povabi v krog »%2$s«",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s pošlje prošnjo za včlanitev v krog »%2$s«",
    "Accept" : "Sprejmi",
    "Refuse" : "Zavrni",
    "Leave the circle" : "Zapusti krog",
    "%s" : "%s",
    "%s owned by %s" : "%s v lasti %s",
    "%s shared a file with \"%s\"." : "%s omogoča souporabo datoteke z »%s«.",
    "%s shared a file with you." : "%s vam omogoča souporabo datoteke.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s vam omogoča souporabo vsebine.\nMorali bi že prejeti ločeno sporočilo s povezavo za dostop po elektronski pošti.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s vam omogoča souporabo vsebine. Morali bi že prejeti ločeno sporočilo s povezavo za dostop po elektronski pošti.",
    "Password to access content shared with you by %1$s" : "%1$s vam pošilja geslo za dostop do vsebine v souporabi.",
    "Password to access content" : "Geslo za dostop do vsebine",
    "Bring cloud-users closer together." : "Potegnite uporabnike oblakov bliže skupaj.",
    "No files in here" : "V mapi ni datotek",
    "No entries found in this folder" : "V tej mapi ni datotek in podmap.",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "Circles" : "Krogi",
    "Circles' files" : "Datoteke kroga",
    "Select circles to filter by" : "Izbor krogov za filtriranje",
    "No circles found" : "Ni najdenih krogov",
    "Please select circles to filter by" : "Izbor krogov za filtriranje",
    "No files found for the selected circles" : "Ni izbranih datotek za izbrane kroge",
    "You created the circle {circle}" : "Ustvarili ste krog {circle}",
    "{author} created the circle {circle}" : "{author} ustvari krog {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Obvestila za dogodke v <strong>krogih</strong>, v katere ste vključeni",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Obvestila za pomembne dogodke v <strong>krogih</strong>, ki jih moderirate",
    "On global events happening in any <strong>Circle</strong>" : "Za splošne dogodke v kateremkoli <strong>krogu</strong>",
    "Join Request" : "Zahteva za pridružitev",
    "Password Protected" : "Zaščiteno z geslom",
    "Circle Invite" : "Povabilo v krog",
    "Email Address" : "Elektronski naslov",
    "Initialisation Nextcloud" : "Začenjanje okolja Nextcloud",
    "Initialisation Circles App" : "Začenjanje programa Krogi",
    "Circle not found" : "Kroga ni mogoče najti",
    "Circle not found " : "Kroga ni mogoče najti",
    "This account is already a member of the circle" : "Ta račun ima že potrjeno članstvo v krogu.",
    "Federated link not found" : "Zvezne povezave ni mogoče najti",
    "The circle is not federated" : "Krog ni zvezni krog",
    "You cannot join this circle" : "V ta krog se brez povabila ni mogoče pridružiti",
    "This member is the owner of the circle" : "Član je lastnik kroga",
    "%s (Circle owned by %s)" : "%s (lastnik kroga je %s)",
    "Personal Circle" : "Osebni krog",
    "You need a specify a type of circle" : "Določiti je treba vrsto kroga",
    "A circle with that name exists" : "Krog s tem imenom že obstaja",
    "This member is not the owner of the circle" : "Ta član ni lastnik kroga",
    "This member is not an admin of the circle" : "Ta član ni skrbnik kroga",
    "Group contains too many members" : "V skupini je preveč članov",
    "This group does not exist" : "Ta skupina ne obstaja.",
    "This group is already linked to the circle" : "Ta skupina je s krogom že povezana.",
    "You cannot edit level in a personal circle" : "Ni mogoče urediti vloge v osebnem krogu",
    "Group cannot be set as owner of a circle" : "Skupine ni mogoče določiti kot lastnika kroga.",
    "now" : "zdaj",
    "This account does not exist" : "Račun ne obstaja",
    "Email format is not valid" : "Zapis elektronskega naslova ni veljaven",
    "This contact is not available" : "Ta stik ni na voljo.",
    "You have no permission to create a new circle" : "Ni ustreznih dovoljenj za ustvarjanje novega kroga.",
    "This item is already shared with this circle" : "Ta predmet je v tem krogu že v souporabi",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Program Krogi omogoča uporabnikom ustvariti lastne skupine uporabnikov, sodelavcev, prijateljev ...\nTe skupine uporabnikov (oziroma »krogov«) je nato mogoče uporabiti kot skupine za souporabo in izmenjavo datotek in podatkov v različnih programih."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
